@@ -8,9 +8,6 @@ has [qw/domain httponly max_age path secure/];
 
 my $ATTR_RE = qr/(Domain|expires|HttpOnly|Max-Age|Path|Secure)/msi;
 
-# DEPRECATED in Leaf Fluttering In Wind!
-sub comment { warn "Mojo::Cookie::Response->comment is DEPRECATED!\n" }
-
 sub expires {
   my ($self, $expires) = @_;
 
@@ -48,7 +45,8 @@ sub parse {
 
       # Attributes
       elsif (my @match = $name =~ $ATTR_RE) {
-        (my $attr = lc $match[0]) =~ tr/-/_/;
+        my $attr = lc $match[0];
+        $attr =~ tr/-/_/;
         $cookies[-1]->$attr($attr =~ /(?:Secure|HttpOnly)/i ? 1 : $value);
       }
     }
@@ -57,9 +55,6 @@ sub parse {
   return \@cookies;
 }
 
-# DEPRECATED in Leaf Fluttering In Wind!
-sub port { warn "Mojo::Cookie::Response->port is DEPRECATED!\n" }
-
 sub to_string {
   my $self = shift;
 
