@@ -321,6 +321,9 @@ L<Mojolicious::Controller> and L<Mojo>.
 
 Routing cache, defaults to a L<Mojo::Cache> object.
 
+  # Disable caching
+  $r->cache(0);
+
 =head2 C<conditions>
 
   my $conditions = $r->conditions;
